#******************************************************************************
#
#       Copyright:      2005-2006 Paul Obermeier (obermeier@poSoft.de)
#
#                       See the file "Tcl3D_License.txt" for information on
#                       usage and redistribution of this file, and for a
#                       DISCLAIMER OF ALL WARRANTIES.
#
#       Module:         Tcl3D -> tcl3dDemoUtil
#       Filename:       tcl3dHeightMap.tcl
#
#       Author:         Paul Obermeier
#
#       Description:    Tcl module to create a heightmap from a photo image.
#                       This functionality is needed for NeHe tutorial 45.
#
#******************************************************************************

# Create two Tcl3D vectors containing the vertices and texture coordinates of
# a heightmap created from the image data of Tk photo phImg.
# The two vectors and the number of vertices generated are returned in a list.

proc tcl3dHeightmapFromPhoto { phImg flHeightScale flResolution } {
    set w [image width  $phImg]
    set h [image height $phImg]
    set n [tcl3dPhotoChans $phImg]
    if { $n < 3 } {
        error "Photo must have 3 or more channels"
    }
    set numVtx [expr {int ($w * $h * 6 / ($flResolution * $flResolution))}]

    set vtxVec [tcl3dVector GLfloat [expr {3 * $numVtx}]]
    set texVec [tcl3dVector GLfloat [expr {2 * $numVtx}]]
    tcl3dPhoto2Heightmap $phImg $vtxVec $texVec $flHeightScale $flResolution
    return [list $vtxVec $texVec $numVtx]
}
